@@ -5,9 +5,9 @@
 ;; Author: precompute <git@precompute.net>
 ;; URL: https://github.com/precompute/hyperstitional-themes
 ;; Created: April 16, 2024
-;; Modified: February 15, 2026
-;; Package-Version: 3.4
-;; Package-Revision: b4bf851ea46a
+;; Modified: September 15, 2025
+;; Package-Version: 20251223.1053
+;; Package-Revision: 37218686986a
 ;; Package-Requires: ((emacs "24.1"))
 
 ;; This program is free software: you can redistribute it and/or modify
@@ -90,10 +90,10 @@ Returns a color in hex as a string."
      `(underline                  ((,class (:underline t))))
      `(variable-pitch             ((,class (:height 1.0))))
      `(fringe                     ((,class (:background ,bg))))
-     `(vertical-border            ((,class (:background ,c0 :foreground ,c0))))
-     `(window-divider             ((,class (:background ,c0 :foreground ,c0))))
-     `(window-divider-first-pixel ((,class (:background ,c0 :foreground ,c0))))
-     `(window-divider-last-pixel  ((,class (:background ,c0 :foreground ,c0))))
+     `(vertical-border            ((,class (:background ,bg :foreground ,bg))))
+     `(window-divider             ((,class (:background ,bg :foreground ,bg))))
+     `(window-divider-first-pixel ((,class (:background ,bg :foreground ,bg))))
+     `(window-divider-last-pixel  ((,class (:background ,bg :foreground ,bg))))
 
      `(default ((,class (:foreground ,fg :background ,bg))))
 
@@ -160,11 +160,11 @@ Returns a color in hex as a string."
      `(font-lock-regexp-grouping-backslash ((,class (:foreground ,c0-dim))))
 
 ;;;;;; Header line and mode line
-     `(mode-line             ((,class (:foreground ,c0 :background ,c6))))
-     `(mode-line-buffer-id   ((,class (:foreground ,c1 :background ,c6))))
-     `(mode-line-emphasis    ((,class (:foreground ,c2 :background ,c6))))
-     `(mode-line-highlight   ((,class (:foreground ,c3 :background ,c6-light))))
-     `(mode-line-inactive    ((,class (:foreground ,c4 :background ,c6-dim))))
+     `(mode-line             ((,class (:inherit variable-pitch :foreground ,c0 :background ,c6))))
+     `(mode-line-buffer-id   ((,class (:inherit variable-pitch :foreground ,c1 :background ,c6))))
+     `(mode-line-emphasis    ((,class (:inherit variable-pitch :foreground ,c2 :background ,c6))))
+     `(mode-line-highlight   ((,class (:inherit variable-pitch :foreground ,c3 :background ,c6-light))))
+     `(mode-line-inactive    ((,class (:inherit variable-pitch :foreground ,c4 :background ,c6-dim))))
      `(header-line           ((,class (:inherit mode-line))))
      `(header-line-inactive  ((,class (:inherit mode-line-inactive))))
      `(header-line-highlight ((,class (:inherit mode-line-highlight))))
@@ -789,10 +789,10 @@ Returns a color in hex as a string."
     (custom-theme-set-faces
      theme-name
      `(fringe                     ((,class (:background ,ww))))
-     `(vertical-border            ((,class (:background ,ra :foreground ,ra))))
-     `(window-divider             ((,class (:background ,ra :foreground ,ra))))
-     `(window-divider-first-pixel ((,class (:background ,ra :foreground ,ra))))
-     `(window-divider-last-pixel  ((,class (:background ,ra :foreground ,ra))))
+     `(vertical-border            ((,class (:background ,ww :foreground ,ww))))
+     `(window-divider             ((,class (:background ,ww :foreground ,ww))))
+     `(window-divider-first-pixel ((,class (:background ,ww :foreground ,ww))))
+     `(window-divider-last-pixel  ((,class (:background ,ww :foreground ,ww))))
 
      `(default ((,class (:foreground ,wa :background ,ww))))
      `(button  ((,class (:background ,be :foreground ,wc :box (:line-width 2 :color ,bb :style released-button)))))
@@ -852,11 +852,11 @@ Returns a color in hex as a string."
      `(font-lock-regexp-grouping-backslash ((,class (:inherit font-lock-regexp-face :underline t))))
 
 ;;;;;; Header line and mode line
-     `(mode-line             ((,class (:foreground ,wb :background ,be))))
-     `(mode-line-buffer-id   ((,class (:foreground ,ba))))
-     `(mode-line-emphasis    ((,class (:foreground ,ra))))
-     `(mode-line-highlight   ((,class (:foreground ,ga))))
-     `(mode-line-inactive    ((,class (:foreground ,wb :background ,bg))))
+     `(mode-line             ((,class (:inherit variable-pitch :foreground ,wb :background ,be))))
+     `(mode-line-buffer-id   ((,class (:inherit variable-pitch :foreground ,ba))))
+     `(mode-line-emphasis    ((,class (:inherit variable-pitch :foreground ,ra))))
+     `(mode-line-highlight   ((,class (:inherit variable-pitch :foreground ,ga))))
+     `(mode-line-inactive    ((,class (:inherit variable-pitch :foreground ,wb :background ,bg))))
      `(header-line           ((,class (:inherit mode-line))))
      `(header-line-inactive  ((,class (:inherit mode-line-inactive))))
      `(header-line-highlight ((,class (:inherit mode-line-highlight))))
@@ -1171,10 +1171,10 @@ Returns a color in hex as a string."
      `(diff-refine-added   ((,class (:foreground ,ww :background ,ga))))
 
 ;;;;;; orderless
-     `(orderless-match-face-0 ((,class (:inverse-video t :background ,bg :weight bold :underline ,bd))))
-     `(orderless-match-face-1 ((,class (:inverse-video t :background ,rg :weight bold :underline ,rd))))
-     `(orderless-match-face-2 ((,class (:inverse-video t :background ,gg :weight bold :underline ,gd))))
-     `(orderless-match-face-3 ((,class (:inverse-video t :background ,wg :weight bold :underline ,wd))))
+     `(orderless-match-face-0 ((,class (:background ,bg :weight bold :underline ,bd))))
+     `(orderless-match-face-1 ((,class (:background ,rg :weight bold :underline ,rd))))
+     `(orderless-match-face-2 ((,class (:background ,gg :weight bold :underline ,gd))))
+     `(orderless-match-face-3 ((,class (:background ,wg :weight bold :underline ,wd))))
 
 ;;;;;; vertico
      `(vertico-current     ((,class (:underline (:position 0 :color ,ra :style dots)))))
